aigra_backend_help: Show 'AIGRA' Backend Setup Help

View source: R/aigra-user-api.R

aigra_backend_helpR Documentation

Show 'AIGRA' Backend Setup Help

Description

Prints a short guide for configuring the external 'AIGRA' backend.

Usage

aigra_backend_help()

Value

A data frame or list returned by the AIGRA tabular generation backend.

Examples

aigra_backend_help()

AIGRA documentation built on July 10, 2026, 5:06 p.m.