aigra_localize_diagram_prompts: Localize AIGRA diagram prompts

View source: R/aigra-diagram-language.R

aigra_localize_diagram_promptsR Documentation

Localize AIGRA diagram prompts

Description

Adds a language instruction to diagram prompts so generated diagrams use the target language for visible labels.

Usage

aigra_localize_diagram_prompts(result, target_language = "English")

Arguments

result

A data frame returned by AIGRA.

target_language

Target language for localized diagram prompts.

Value

Updated result data frame.


AIGRA documentation built on July 10, 2026, 5:06 p.m.