aigra_repair_diagram_prompts: Repair diagram prompts for diagram-dependent AIGRA results

View source: R/aigra-diagram-repair.R

aigra_repair_diagram_promptsR Documentation

Repair diagram prompts for diagram-dependent AIGRA results

Description

Strengthens diagram prompts when a generated item requires a figure but the prompt is too vague for solving/review.

Usage

aigra_repair_diagram_prompts(result)

Arguments

result

A data frame returned by AIGRA.

Value

Updated result data frame.


AIGRA documentation built on July 10, 2026, 5:06 p.m.