aigra_set_api_keys: Set API keys for AIGRA providers

View source: R/aigra-user-api.R View source: R/aigra-api-keys.R

aigra_set_api_keysR Documentation

Set API keys for AIGRA providers

Description

Stores API keys in the current R session so that the Python backend can use them.

Sets API keys for supported providers from within R. These environment variables are inherited by the external 'Python' backend when generation functions are called.

Usage

aigra_set_api_keys(
  gemini.API = NULL,
  openai.API = NULL,
  groq.API = NULL,
  anthropic.API = NULL
)

aigra_set_api_keys(
  gemini.API = NULL,
  openai.API = NULL,
  groq.API = NULL,
  anthropic.API = NULL
)

Arguments

gemini.API

Optional 'Gemini' API key.

openai.API

Optional 'OpenAI' API key.

groq.API

Optional 'Groq' API key.

anthropic.API

Optional 'Anthropic' API key.

Value

Invisibly returns TRUE.

A data frame or list returned by the AIGRA tabular generation backend.

Examples

keys <- aigra_set_api_keys()
is.logical(keys)

AIGRA documentation built on July 10, 2026, 5:06 p.m.