View source: R/aigra-validation.R
| aigra_validate_tabular_items | R Documentation |
Checks a CSV or Excel item bank before parsing or generation.
aigra_validate_tabular_items(file_path)
file_path |
Path to CSV or Excel item bank. |
A list containing validation status, issues, and a summary.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.