View source: R/aigra-user-api.R
| aigra_backend_help | R Documentation |
Prints a short guide for configuring the external 'AIGRA' backend.
aigra_backend_help()
A data frame or list returned by the AIGRA tabular generation backend.
aigra_backend_help()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.