View source: R/aigra-diagram-language.R
| aigra_localize_diagram_prompts | R Documentation |
Adds a language instruction to diagram prompts so generated diagrams use the target language for visible labels.
aigra_localize_diagram_prompts(result, target_language = "English")
result |
A data frame returned by AIGRA. |
target_language |
Target language for localized diagram prompts. |
Updated result data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.