View source: R/aigra-diagram-repair.R
| aigra_repair_diagram_prompts | R Documentation |
Strengthens diagram prompts when a generated item requires a figure but the prompt is too vague for solving/review.
aigra_repair_diagram_prompts(result)
result |
A data frame returned by AIGRA. |
Updated result data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.