| aigra_status | R Documentation |
Checks whether the R package can access the Python backend.
aigra_status(backend_path = NULL)
backend_path |
Optional path to the AIGRA_BACKEND folder. |
A list containing backend path, Python path, Python version, and import status.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.